==> ark-24.05.2.tar.xz: ark-24.05.2/plugins/cliunarchiverplugin/kerfuffle_cliunarchiver.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract RAR and LHA archives",
        "Description[ar]": "يفتح ويستخرج أرشيفات RAR و LHA",
        "Description[ast]": "Abre y estrae archivos RAR y LHA",
        "Description[az]": "RAR və LHA arxivlərini açın və çıxarın",
        "Description[be]": "Адкрыццё і распакоўванне архіваў у фарматах RAR і LHA",
        "Description[bg]": "Отваряне и извличане на архиви RAR и LHA",
        "Description[ca@valencia]": "Obri i extrau arxius RAR i LHA",
        "Description[ca]": "Obre i extreu arxius RAR i LHA",
        "Description[cs]": "Otevřít a rozbalit archivy RAR a LHA",
        "Description[da]": "Åbn og udpak RAR- og LHA-arkiver",
        "Description[de]": "Öffnen und Entpacken von RAR- und LHA-Archiven",
        "Description[el]": "Άνοιγμα και εξαγωγή αρχειοθηκών RAR και LHA",
        "Description[eo]": "Malfermi kaj malpaki RAR- kaj LHA-arkivojn",
        "Description[es]": "Abrir y extraer archivos RAR y LHA",
        "Description[eu]": "Ireki eta erauzi RAR eta LHA artxiboak",
        "Description[fi]": "Avaa ja pura RAR- ja LHA-arkistoja",
        "Description[fr]": "Ouvre et extrait les archives « RAR » et « LHA »",
        "Description[gl]": "Abrir e extraer arquivos RAR e LHA.",
        "Description[he]": "פתיחה וחילוץ ארכיוני RAR ו־LHA",
        "Description[hu]": "RAR és LHA archívumok megnyitása és kibontása",
        "Description[ia]": "Aperir e extraher archivos RAR e LHA ",
        "Description[id]": "Buka dan ekstrak arsip RAR dan LHA",
        "Description[ie]": "Aperter e extraer archives RAR e LHA",
        "Description[is]": "Opna og afþjappa RAR- og LHA-safnskrár",
        "Description[it]": "Apri ed estrai archivi RAR e LHA",
        "Description[ja]": "RAR および LHA アーカイブの閲覧と展開",
        "Description[ka]": "RAR და LHA არქივების გახსნა და გაშლა",
        "Description[ko]": "RAR 및 LHA 압축 파일 열고 풀기",
        "Description[lv]": "Atver un atspiež RAR un LHA arhīvus",
        "Description[nl]": "Open en pak RAR- en LHA-archieven uit",
        "Description[nn]": "Opna og pakk ut RAR- og LHA-arkiv",
        "Description[pa]": "RAR ਅਤੇ LHA ਅਕਾਇਵਾਂ ਨੂੰ ਖੋਲ੍ਹੋ ਅਤੇ ਖਿਲਾਰੋ",
        "Description[pl]": "Otwiera i wypakowuje archiwa RAR oraz LHA",
        "Description[pt]": "Abrir e extrair os pacotes RAR e LHA",
        "Description[pt_BR]": "Abrir e extrair arquivos RAR e LHA",
        "Description[ro]": "Deschide și extrage arhive RAR și LHA",
        "Description[ru]": "Открытие и распаковка архивов RAR и LHA",
        "Description[sk]": "Otvorenie a extrahovanie archívov RAR a LHA",
        "Description[sl]": "Odprite in razširite arhive RAR in LHA",
        "Description[sv]": "Öppna och extrahera RAR- och LHA-arkiv",
        "Description[tr]": "RAR ve LHA arşivlerini açın ve çıkarın",
        "Description[uk]": "Здатен відкривати і видобувати архіви RAR і LHA",
        "Description[x-test]": "xxOpen and extract RAR and LHA archivesxx",
        "Description[zh_CN]": "打开和解压 RAR 和 LHA 压缩文件",
        "Description[zh_TW]": "開啟並解壓縮 RAR 與 LHA 壓縮檔",
        "MimeTypes": [
            "application/vnd.rar",
            "application/x-lha",
            "application/x-stuffit"
        ],
        "Name": "The Unarchiver plugin",
        "Name[ar]": "ملحق فك الأرشيف",
        "Name[ast]": "Plugin de The Unarchiver",
        "Name[az]": "Unarchive qoşması",
        "Name[be]": "Убудова Unarchiver",
        "Name[bg]": "Приставка Unarchiver",
        "Name[ca@valencia]": "Connector d'Unarchiver",
        "Name[ca]": "Connector de l'Unarchiver",
        "Name[cs]": "Modul pro Unarchiver",
        "Name[da]": "Unarchiver-pluginet",
        "Name[de]": "Unarchiver-Modul",
        "Name[el]": "Πρόσθετο Unarchiver",
        "Name[eo]": "The Unarchiver-kromaĵo",
        "Name[es]": "El complemento de Unarchiver",
        "Name[et]": "Unarchiveri plugin",
        "Name[eu]": "Unarchiver plugina",
        "Name[fi]": "Unarchiver-tuki",
        "Name[fr]": "Module externe d'extraction d'archive",
        "Name[gl]": "Complemento de desarquivar",
        "Name[he]": "תוסף חילוץ ארכיונים",
        "Name[hu]": "Az Unarchiver bővítmény",
        "Name[ia]": "Le Unarchiver plugin - plugin per de-archivar",
        "Name[id]": "Plugin Unarchiver",
        "Name[ie]": "Plugin de Unarchiver",
        "Name[is]": "Unarchiver-viðbótin",
        "Name[it]": "Estensione The Unarchiver",
        "Name[ja]": "Unarchiver プラグイン",
        "Name[ka]": "Unarchiver -ის მხარდაჭერა",
        "Name[ko]": "The Unarchiver 플러그인",
        "Name[lv]": "„Unarchiver“ spraudnis",
        "Name[nl]": "De plug-in voor uit archief halen",
        "Name[nn]": "The Unarchiver-tillegg",
        "Name[pa]": "Unarchiver ਪਲੱਗਇਨ",
        "Name[pl]": "Wtyczka wypakowywacza",
        "Name[pt]": "O 'plugin' do Unarchiver",
        "Name[pt_BR]": "Plugin Unarchiver",
        "Name[ro]": "Extensie de dezarhivare",
        "Name[ru]": "Модуль Unarchiver",
        "Name[sk]": "Plugin Unarchiver",
        "Name[sl]": "Vstavek Unarchiver",
        "Name[sr@ijekavian]": "Прикључак Унархивера",
        "Name[sr@ijekavianlatin]": "Priključak Unarchivera",
        "Name[sr@latin]": "Priključak Unarchivera",
        "Name[sr]": "Прикључак Унархивера",
        "Name[sv]": "Unarchiver-insticksprogram",
        "Name[tr]": "Unarchiver eklentisi",
        "Name[uk]": "Додаток Unarchiver",
        "Name[x-test]": "xxThe Unarchiver pluginxx",
        "Name[zh_CN]": "Unarchiver 插件",
        "Name[zh_TW]": "解壓縮外掛程式",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadOnlyExecutables": [
        "lsar",
        "unar"
    ],
    "X-KDE-Kerfuffle-ReadWrite": false,
    "X-KDE-Priority": 100,
    "application/vnd.rar": {
        "HeaderEncryption": true
    }
}

==> ark-24.12.0.tar.xz: ark-24.12.0/plugins/cliunarchiverplugin/kerfuffle_cliunarchiver.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract RAR and LHA archives",
        "Description[ar]": "يفتح ويستخرج أرشيفات RAR و LHA",
        "Description[ast]": "Abre y estrae archivos RAR y LHA",
        "Description[az]": "RAR və LHA arxivlərini açın və çıxarın",
        "Description[be]": "Адкрыццё і распакоўванне архіваў у фарматах RAR і LHA",
        "Description[bg]": "Отваряне и извличане на архиви RAR и LHA",
        "Description[ca@valencia]": "Obri i extrau arxius RAR i LHA",
        "Description[ca]": "Obre i extreu arxius RAR i LHA",
        "Description[cs]": "Otevřít a rozbalit archivy RAR a LHA",
        "Description[da]": "Åbn og udpak RAR- og LHA-arkiver",
        "Description[de]": "Öffnen und Entpacken von RAR- und LHA-Archiven",
        "Description[el]": "Άνοιγμα και εξαγωγή αρχειοθηκών RAR και LHA",
        "Description[en_GB]": "Open and extract RAR and LHA archives",
        "Description[eo]": "Malfermi kaj malpaki RAR- kaj LHA-arkivojn",
        "Description[es]": "Abrir y extraer archivos RAR y LHA",
        "Description[eu]": "Ireki eta erauzi RAR eta LHA artxiboak",
        "Description[fi]": "Avaa ja pura RAR- ja LHA-arkistoja",
        "Description[fr]": "Ouvre et extrait les archives « RAR » et « LHA »",
        "Description[gl]": "Abrir e extraer arquivos RAR e LHA.",
        "Description[he]": "פתיחה וחילוץ ארכיוני RAR ו־LHA",
        "Description[hu]": "RAR és LHA archívumok megnyitása és kibontása",
        "Description[ia]": "Aperir e extraher archivos RAR e LHA ",
        "Description[id]": "Buka dan ekstrak arsip RAR dan LHA",
        "Description[ie]": "Aperter e extraer archives RAR e LHA",
        "Description[is]": "Opna og afþjappa RAR- og LHA-safnskrár",
        "Description[it]": "Apri ed estrai archivi RAR e LHA",
        "Description[ja]": "RAR および LHA アーカイブの閲覧と展開",
        "Description[ka]": "RAR და LHA არქივების გახსნა და გაშლა",
        "Description[ko]": "RAR 및 LHA 압축 파일 열고 풀기",
        "Description[lv]": "Atver un atspiež RAR un LHA arhīvus",
        "Description[nl]": "Open en pak RAR- en LHA-archieven uit",
        "Description[nn]": "Opna og pakk ut RAR- og LHA-arkiv",
        "Description[pa]": "RAR ਅਤੇ LHA ਅਕਾਇਵਾਂ ਨੂੰ ਖੋਲ੍ਹੋ ਅਤੇ ਖਿਲਾਰੋ",
        "Description[pl]": "Otwiera i wypakowuje archiwa RAR oraz LHA",
        "Description[pt]": "Abrir e extrair os pacotes RAR e LHA",
        "Description[pt_BR]": "Abrir e extrair arquivos RAR e LHA",
        "Description[ro]": "Deschide și extrage arhive RAR și LHA",
        "Description[ru]": "Открытие и распаковка архивов RAR и LHA",
        "Description[sk]": "Otvorenie a extrahovanie archívov RAR a LHA",
        "Description[sl]": "Odprite in razširite arhive RAR in LHA",
        "Description[sv]": "Öppna och extrahera RAR- och LHA-arkiv",
        "Description[tr]": "RAR ve LHA arşivlerini açın ve çıkarın",
        "Description[uk]": "Здатен відкривати і видобувати архіви RAR і LHA",
        "Description[x-test]": "xxOpen and extract RAR and LHA archivesxx",
        "Description[zh_CN]": "打开和解压 RAR 和 LHA 压缩文件",
        "Description[zh_TW]": "開啟並解壓縮 RAR 與 LHA 壓縮檔",
        "MimeTypes": [
            "application/vnd.rar",
            "application/x-lha",
            "application/x-stuffit"
        ],
        "Name": "The Unarchiver plugin",
        "Name[ar]": "ملحق فك الأرشيف",
        "Name[ast]": "Plugin de The Unarchiver",
        "Name[az]": "Unarchive qoşması",
        "Name[be]": "Убудова Unarchiver",
        "Name[bg]": "Приставка Unarchiver",
        "Name[ca@valencia]": "Connector d'Unarchiver",
        "Name[ca]": "Connector de l'Unarchiver",
        "Name[cs]": "Modul pro Unarchiver",
        "Name[da]": "Unarchiver-pluginet",
        "Name[de]": "Unarchiver-Modul",
        "Name[el]": "Πρόσθετο Unarchiver",
        "Name[en_GB]": "The Unarchiver plugin",
        "Name[eo]": "The Unarchiver-kromaĵo",
        "Name[es]": "El complemento de Unarchiver",
        "Name[et]": "Unarchiveri plugin",
        "Name[eu]": "Unarchiver plugina",
        "Name[fi]": "Unarchiver-tuki",
        "Name[fr]": "Module externe d'extraction d'archive",
        "Name[gl]": "Complemento de desarquivar",
        "Name[he]": "תוסף חילוץ ארכיונים",
        "Name[hu]": "Az Unarchiver bővítmény",
        "Name[ia]": "Le Unarchiver plugin - plugin per de-archivar",
        "Name[id]": "Plugin Unarchiver",
        "Name[ie]": "Plugin de Unarchiver",
        "Name[is]": "Unarchiver-viðbótin",
        "Name[it]": "Estensione The Unarchiver",
        "Name[ja]": "Unarchiver プラグイン",
        "Name[ka]": "Unarchiver -ის მხარდაჭერა",
        "Name[ko]": "The Unarchiver 플러그인",
        "Name[lv]": "„Unarchiver“ spraudnis",
        "Name[nl]": "De plug-in voor uit archief halen",
        "Name[nn]": "The Unarchiver-tillegg",
        "Name[pa]": "Unarchiver ਪਲੱਗਇਨ",
        "Name[pl]": "Wtyczka wypakowywacza",
        "Name[pt]": "O 'plugin' do Unarchiver",
        "Name[pt_BR]": "Plugin Unarchiver",
        "Name[ro]": "Extensie de dezarhivare",
        "Name[ru]": "Модуль Unarchiver",
        "Name[sk]": "Plugin Unarchiver",
        "Name[sl]": "Vstavek Unarchiver",
        "Name[sr@ijekavian]": "Прикључак Унархивера",
        "Name[sr@ijekavianlatin]": "Priključak Unarchivera",
        "Name[sr@latin]": "Priključak Unarchivera",
        "Name[sr]": "Прикључак Унархивера",
        "Name[sv]": "Unarchiver-insticksprogram",
        "Name[tr]": "Unarchiver eklentisi",
        "Name[uk]": "Додаток Unarchiver",
        "Name[x-test]": "xxThe Unarchiver pluginxx",
        "Name[zh_CN]": "Unarchiver 插件",
        "Name[zh_TW]": "解壓縮外掛程式",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadOnlyExecutables": [
        "lsar",
        "unar"
    ],
    "X-KDE-Kerfuffle-ReadWrite": false,
    "X-KDE-Priority": 100,
    "application/vnd.rar": {
        "HeaderEncryption": true
    }
}
